/* This file was generated by syncqt. */
#ifndef QT_QTDATAVISUALIZATION_VERSION_H
#define QT_QTDATAVISUALIZATION_VERSION_H

#define QTDATAVISUALIZATION_VERSION_STR "5.15.16"

#define QTDATAVISUALIZATION_VERSION 0x050F10

#endif // QT_QTDATAVISUALIZATION_VERSION_H
